@@ -95,10 +95,10 @@ def run_api():
 
 def check_api():
     svars = variables()
-    file_path = glob.glob(XML_LOCAL_PATH)
+    file_path = sorted(glob.glob(XML_LOCAL_PATH))
 
     if len(file_path > 0):
-        file_path = file_path[0]
+        file_path = file_path[-1]
         debug.log('glob filepath: {}'.format(file_path))
 
         if check_too_old(file_path, MAX_FILE_AGE*2):
