@@ -99,9 +99,10 @@ def run_api(id, key):
 
         for i in range(100000):
             params['page'] = page
-            response = request(URL_STATIONS, HEADERS, params)
+            response, is_error = request(URL_STATIONS, HEADERS, params)
 
-            if response.status_code != 200:
+            if is_error:
+                debug.log('request {}: {} -> {}'.format(response['type'], response['reason'], response['message']))
                 debug.log('No more pages found for stations')
                 break
 
@@ -141,9 +142,10 @@ def run_api(id, key):
 
         for i in range(100000):
             params['page'] = page
-            response = request(URL_FLIGHTS, HEADERS, params)
+            response, is_error = request(URL_FLIGHTS, HEADERS, params)
 
-            if response.status_code != 200:
+            if is_error:
+                debug.log('request {}: {} -> {}'.format(response['type'], response['reason'], response['message']))
                 debug.log('No more flights found.')
                 break
 
@@ -172,10 +174,10 @@ def run_api(id, key):
 
 def check_api():
     svars = variables()
-    file_path = glob.glob(XML_LOCAL_PATH_FLIGHTS)
+    file_path = sorted(glob.glob(XML_LOCAL_PATH_FLIGHTS))
 
     if len(file_path) > 0:
-        file_path = file_path[0]
+        file_path = file_path[-1]
         debug.log('glob filepath: {}'.format(file_path))
 
         if check_too_old(file_path, FLIGHTS_MAX_FILE_AGE):
