@@ -49,12 +49,19 @@ def run_api():
 
     if check_too_old(JSON_FILE_PATH, MAX_FILE_AGE):
         with open(JSON_FILE_PATH, 'w') as file:
-            response = request_json(URL, params=PARAMS).get('value', None)
-            if response is None:
-                warn.log('response is empty')
+            response, is_error = request_json(URL, params=PARAMS)
+            if is_error:
+                if response['type'] == 'ERROR':
+                    error.log('request {} -> {}'.format(response['reason'], response['message']))
+                elif response['type'] == 'WARN':
+                    warn.log('request {} -> {}'.format(response['reason'], response['message']))
             else:
-                debug.log(response)
-                json.dump(response, file)
+                response = response.get('value', None)
+                if response is None:
+                    warn.log('response is empty')
+                else:
+                    debug.log(response)
+                    json.dump(response, file)
     else:
         debug.log('File not old enough to update')
 
