@@ -58,7 +58,14 @@ def run_api(api_key, max_minutes, max_characters, max_items):
     change_language(DUTCH_INDEX)
 
     if check_too_old(xml_temp_path, max_file_age):
-        response_json = request_json(URL, headers, params, False)
+        response_json, is_error = request_json(URL, headers, params, False)
+
+        if is_error:
+            if response_json['type'] == 'ERROR':
+                error.log('request {} -> {}'.format(response_json['reason'], response_json['message']))
+            elif response_json['type'] == 'WARN':
+                warn.log('request {} -> {}'.format(response_json['reason'], response_json['message']))
+            exit()
 
         root = ET.Element("root")
 
@@ -94,10 +101,10 @@ def check_api(max_minutes):
 
     debug.log('local path: {}'.format(file_path))
 
-    file_path = glob.glob(file_path)
+    file_path = sorted(glob.glob(file_path))
 
     if len(file_path) > 0:
-        file_path = file_path[0]
+        file_path = file_path[-1]
         debug.log('glob filepath: {}'.format(file_path))
 
         if check_too_old(file_path, max_file_age):
