@@ -111,10 +111,10 @@ def check_api(news_categories):
 
     for category in news_categories:
         debug.log('category: {}'.format(category))
-        file_path = glob.glob(os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, '{}*.xml'.format(category.lower())))
+        file_path = sorted(glob.glob(os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, '{}*.xml'.format(category.lower()))))
         
         if len(file_path) > 0:
-            file_path = file_path[0]
+            file_path = file_path[-1]
             debug.log('glob filepath: {}'.format(file_path))
 
             if check_too_old(file_path, MAX_FILE_AGE*2):
