@@ -67,7 +67,14 @@ def run_api(jam_type, max_closest, max_longest, own_coordinates, only_highways):
     update_directories_api(NAME)
 
     if (check_too_old(XML_TEMP_PATH_LONGEST, MAX_FILE_AGE) and max_longest > 0) or (check_too_old(XML_TEMP_PATH_CLOSEST, MAX_FILE_AGE) and max_closest > 0):
-        traffic_info = request_json(URL, HEADERS, PARAMS)
+        traffic_info, is_error = request_json(URL, HEADERS, PARAMS)
+
+        if is_error:
+            if traffic_info['type'] == 'ERROR':
+                error.log('request {} -> {}'.format(traffic_info['reason'], traffic_info['message']))
+            elif traffic_info['type'] == 'WARN':
+                warn.log('request {} -> {}'.format(traffic_info['reason'], traffic_info['message']))
+            exit()
 
         circumstances = parse_circumstances(get_circumstances(traffic_info), own_coordinates, only_highways)
         jams = get_jams(circumstances, jam_type)
@@ -110,11 +117,11 @@ def check_api():
 
     file_exists = [True, True]
 
-    file_path_longest = glob.glob(XML_LOCAL_LONGEST)
-    file_path_closest = glob.glob(XML_LOCAL_CLOSEST)
+    file_path_longest = sorted(glob.glob(XML_LOCAL_LONGEST))
+    file_path_closest = sorted(glob.glob(XML_LOCAL_CLOSEST))
 
     if len(file_path_longest) > 0:
-        file_path_longest = file_path_longest[0]
+        file_path_longest = file_path_longest[-1]
         debug.log('glob filepath: {}'.format(file_path_longest))
 
         if check_too_old(file_path_longest, MAX_FILE_AGE*2):
@@ -130,7 +137,7 @@ def check_api():
         file_exists[0] = False
 
     if len(file_path_closest) > 0:
-        file_path_closest = file_path_closest[0]
+        file_path_closest = file_path_closest[-1]
         debug.log('glob filepath: {}'.format(file_path_closest))
 
         if check_too_old(file_path_closest, MAX_FILE_AGE*2):
