@@ -28,6 +28,8 @@ NAME = APIS['weather']
 XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, 'weather.xml')
 XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'weather*.xml')
 
+ICONS_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'icons')
+
 MAX_FILE_AGE = 60 * 60
 MAX_FILE_AGE_IMAGES = 60 * 60 * 6
 
@@ -132,13 +134,25 @@ def run_api(api_key, icon_set, location='', units='metric', lang='nl', coordinat
     update_directories_api(NAME)
     change_language(DUTCH_INDEX)
 
+    local_icons = glob.glob(os.path.join(ICONS_LOCAL_PATH, icon_set, '*'))
+
+    if not len(local_icons) == len(list_files(url_icons, extensions)):
+        download_icons(url_icons, extensions, temp_folder_icons, icon_set)
+
     if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
 
         download_icons(url_icons, extensions, temp_folder_icons, icon_set)
         
         root = ET.Element("root")
 
-        current_weather = request_json(URL_TODAY, params=params)
+        current_weather, is_error = request_json(URL_TODAY, params=params)
+
+        if is_error:
+            if current_weather['type'] == 'ERROR':
+                error.log('request {} -> {}'.format(current_weather['reason'], current_weather['message']))
+            elif current_weather['type'] == 'WARN':
+                warn.log('request {} -> {}'.format(current_weather['reason'], current_weather['message']))
+            exit()
 
         item = ET.SubElement(root, 'currentWeather')
         ET.SubElement(item, "location").text = get_location(current_weather)
@@ -161,7 +175,14 @@ def run_api(api_key, icon_set, location='', units='metric', lang='nl', coordinat
 
         params['cnt'] = 6
 
-        days_weather = request_json(URL_DAYS, params=params)
+        days_weather, is_error = request_json(URL_DAYS, params=params)
+
+        if is_error:
+            if days_weather['type'] == 'ERROR':
+                error.log('request {} -> {}'.format(days_weather['reason'], days_weather['message']))
+            elif days_weather['type'] == 'WARN':
+                warn.log('request {} -> {}'.format(days_weather['reason'], days_weather['message']))
+            exit()
 
         days = ET.SubElement(root, "days")
 
