@@ -3,7 +3,7 @@ import time
 from imghdr import what
 import shutil
 import requests
-from firstimpression.scala import install_content
+from firstimpression.scala import install_content, Log
 from firstimpression.api.request import request_json
 from firstimpression.constants import TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, PLACEHOLDER_FOLDER, IMG_EXTENSIONS
 import xml.etree.ElementTree as ET
@@ -45,6 +45,12 @@ def download_media(media_link, subdirectory, temp_folder, filename=None):
 
     response = requests.get(media_link, stream=True)
 
+    try:
+        response.raise_for_status()
+    except requests.exceptions.HTTPError as e: 
+        Log('ERROR', 'image_download').log('{}'.format(e))
+        exit()
+
     with open(media_path, 'wb') as writefile:
         shutil.copyfileobj(response.raw, writefile)
 
@@ -84,7 +90,15 @@ def xml_to_root(path):
     return root
 
 def list_files(url, extensions):
-    response = request_json(url)
+    response, is_error = request_json(url)
+
+    if is_error:
+        if response['type'] == 'ERROR':
+            Log('ERROR', 'list_files').log('request {} -> {}'.format(response['reason'], response['message']))
+        elif response['type'] == 'WARN':
+            Log('WARN', 'list_files').log('request {} -> {}'.format(response['reason'], response['message']))
+        exit()
+
     all_elements = response.get('data', [])
     select_elements = [elem for elem in all_elements if '.' + elem.split('.')[-1] in extensions]
     return select_elements
